@@ -1,4 +1,4 @@
-/* $Id: open_suid.c,v 1.9 2003/10/19 16:55:43 carlos Exp $ */
+/* $Id: open_suid.c,v 1.11 2005/08/02 09:47:20 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,7 +23,7 @@
 
 #include <glibtop.h>
 #include <glibtop/open.h>
-
+#include <glibtop/init_hooks.h>
 #include <glibtop_suid.h>
 
 #include <unistd.h>
@@ -35,7 +35,7 @@ void
 glibtop_init_p (glibtop *server, const unsigned long features,
 		const unsigned flags)
 {
-	glibtop_init_func_t *init_fkt;
+	const glibtop_init_func_t *init_fkt;
 
 	if (server == NULL)
 		glibtop_error_r (NULL, "glibtop_init_p (server == NULL)");
@@ -47,7 +47,7 @@ glibtop_init_p (glibtop *server, const unsigned long features,
 
 		for (init_fkt = _glibtop_init_hook_p; *init_fkt; init_fkt++)
 			(*init_fkt) (server);
-		
+
 		server->flags |= _GLIBTOP_INIT_STATE_INIT;
 	}
 }
@@ -61,7 +61,7 @@ glibtop_open_p (glibtop *server, const char *program_name,
 	/* !!! WE ARE ROOT HERE - CHANGE WITH CAUTION !!! */
 
 	server->name = program_name;
-	
+
 	server->machine.uid = getuid ();
 	server->machine.euid = geteuid ();
 	server->machine.gid = getgid ();
@@ -69,22 +69,22 @@ glibtop_open_p (glibtop *server, const char *program_name,
 
 	server->machine.proctable_entries = table
 		(TBL_PROCINFO, 0, NULL, INT_MAX, 0);
-        
+
 	/* Drop priviledges; we only become root when necessary.
-	
+
 	   setreuid (ruid, euid) - set real and effective user id;
 	   setregid (rgid, egid) - set real and effective group id;
-	   
+
 	 */
-	
+
 	if (setreuid (server->machine.euid, server->machine.uid))
 		_exit (1);
-		
+
 	if (setregid (server->machine.egid, server->machine.gid))
 		_exit (1);
 
 	/* !!! END OF SUID ROOT PART !!! */
-		
+
 	/* Our effective uid is now those of the user invoking the server,
 	   so we do no longer have any priviledges.
 	 */
